@@ -20,10 +20,12 @@
 #' @family gtsummary output types
 #' @author Daniel D. Sjoberg
 #' @examples
+#' \donttest{
 #' trial %>%
 #'   tbl_summary(by = trt) %>%
 #'   bold_labels() %>%
 #'   as_kable()
+#' }
 as_kable <- function(x, ..., include = everything(), return_calls = FALSE,
                      exclude = NULL) {
   .assert_class(x, "gtsummary")
@@ -106,7 +108,7 @@ table_styling_to_kable_calls <- function(x, ...) {
       col.names = dplyr::filter(x$table_styling$header, .data$hide == FALSE)$label,
       align =
         filter(x$table_styling$header, .data$hide == FALSE) %>%
-        dplyr::pull(.data$align) %>%
+        dplyr::pull("align") %>%
         stringr::str_sub(1, 1)
     ) %>%
     # update with any args from theme element
