@@ -28,7 +28,7 @@
 #' merely takes the result and puts it in `broom::tidy()` format. To use this
 #' function with `tbl_regression()`, pass a function with the arguments for
 #' `tidy_robust()` populated. This is easily done using `purrr::partial()` e.g.
-#' `tbl_regression(tidy_fun = partial(tidy_robust, vcov_estimation = "CL"))`
+#' `tbl_regression(tidy_fun = partial(tidy_robust, vcov = "CL"))`
 #'
 #' - `pool_and_tidy_mice()` tidier to report models resulting from multiply imputed data
 #' using the mice package. Pass the mice model object *before* the model results
@@ -45,7 +45,7 @@
 #' @inheritParams add_global_p
 #' @param pool.args named list of arguments passed to `mice::pool()` in
 #' `pool_and_tidy_mice()`. Default is `NULL`
-#' @param vcov_estimation,vcov_type,vcov_args arguments passed to
+#' @param vcov,vcov_args arguments passed to
 #' `parameters::model_parameters()`
 #' @param ... arguments passed to method;
 #' - `pool_and_tidy_mice()`: `mice::tidy(x, ...)`
@@ -181,8 +181,7 @@ tidy_robust <- function(x,
                         exponentiate = FALSE,
                         conf.level = 0.95,
                         conf.int = TRUE,
-                        vcov_estimation = NULL, #type of covariance matrix
-                        vcov_type = NULL, #type of robust estimation
+                        vcov = "HC", #type of robust estimation
                         vcov_args = NULL, #specify the cluster-structure
                         ...,
                         quiet = FALSE) {
@@ -193,8 +192,8 @@ tidy_robust <- function(x,
   lst_model_parameters_args <-
     rlang::inject(list(ci = !!conf.level,
                        robust = TRUE,
-                       vcov_estimation = !!vcov_estimation,
-                       vcov_type = !!vcov_type,
+                       vcov = !!vcov,
+                       vcov_args = !!vcov_args,
                        !!!dots)) %>%
     purrr::compact()
 
@@ -248,10 +247,11 @@ pool_and_tidy_mice <- function(x, pool.args = NULL, ..., quiet = FALSE) {
 #' @rdname custom_tidiers
 #' @export
 tidy_gam <- function(x, conf.int = FALSE, exponentiate = FALSE, conf.level = 0.95, ...) {
-  broom::tidy(x,
-              conf.int = conf.int,
-              conf.level = conf.level,
-              parametric = TRUE, ...
+  suppressWarnings(
+    broom::tidy(x,
+                conf.int = conf.int,
+                conf.level = conf.level,
+                parametric = TRUE, ...)
   ) %>%
     # exponentiate coefs (GAM tidier does not have an `exponentiate=` argument)
     dplyr::mutate_at(
@@ -262,7 +262,7 @@ tidy_gam <- function(x, conf.int = FALSE, exponentiate = FALSE, conf.level = 0.9
     ) %>%
     dplyr::mutate(parametric = TRUE) %>%
     dplyr::bind_rows(
-      broom::tidy(x, parametric = FALSE, ...) %>%
+      suppressWarnings(broom::tidy(x, parametric = FALSE, ...)) %>%
         dplyr::mutate(parametric = FALSE)
     ) %>%
     dplyr::relocate("parametric", .after = dplyr::last_col())
