@@ -96,7 +96,6 @@ modify_table_styling <- function(x,
   # checking inputs ------------------------------------------------------------
   .assert_class(x, "gtsummary")
 
-  if (is.null(x$table_styling)) x <- .convert_table_header_to_styling(x)
   text_interpret <- match.arg(text_interpret) %>% {
     paste0("gt::", .)
   }
@@ -225,7 +224,7 @@ modify_table_styling <- function(x,
         format_type = text_format,
         undo_text_format = undo_text_format
       ) %>%
-      purrr::cross_df() %>%
+      {tidyr::expand_grid(!!!.)} %>%
       {
         bind_rows(x$table_styling$text_format, .)
       }
@@ -239,7 +238,7 @@ modify_table_styling <- function(x,
         rows = list(rows),
         symbol = missing_symbol
       ) %>%
-      purrr::cross_df() %>%
+      {tidyr::expand_grid(!!!.)} %>%
       {
         bind_rows(x$table_styling$fmt_missing, .)
       }
