@@ -57,5 +57,5 @@ tbl_butcher <- function(x, include = NULL) {
     rlang::set_names(element_names)
 
   # remove elements and returned reduced object --------------------------------
-  purrr::list_modify(x, !!!lst_nulls)
+  utils::modifyList(x, val = lst_nulls)
 }
