@@ -19,6 +19,7 @@
 #' @export
 #'
 #' @examples
+#' \donttest{
 #' # Example 1 ----------------------------------
 #' tbl_continuous_ex1 <-
 #'   tbl_continuous(
@@ -35,14 +36,19 @@
 #'     variable = age,
 #'     include = c(trt, grade)
 #'   )
+#' }
 #' @section Example Output:
 #' \if{html}{Example 1}
 #'
-#' \if{html}{\figure{tbl_continuous_ex1.png}{options: width=38\%}}
+#' \if{html}{\out{
+#' `r man_create_image_tag(file = "tbl_continuous_ex1.png", width = "38")`
+#' }}
 #'
 #' \if{html}{Example 2}
 #'
-#' \if{html}{\figure{tbl_continuous_ex2.png}{options: width=35\%}}
+#' \if{html}{\out{
+#' `r man_create_image_tag(file = "tbl_continuous_ex2.png", width = "35")`
+#' }}
 
 tbl_continuous <- function(data,
                            variable,
@@ -103,12 +109,12 @@ tbl_continuous <- function(data,
   result <-
     tbl_custom_summary(
       data, data,
-      by = by,
+      by = all_of(by),
       stat_fns = everything() ~ continuous_summary(variable),
       statistic = statistic,
       digits = digits,
       label = label,
-      include = include,
+      include = all_of(include),
       type = all_of(include %>% setdiff(c(variable, by))) ~ "categorical"
     ) %>%
     modify_footnote(
