@@ -351,6 +351,15 @@ tbl_custom_summary <- function(
         by = "column"
       )
   }
+  else {
+    x$table_styling$header <-
+      x$table_styling$header %>%
+      mutate(
+        modify_stat_n = .data$modify_stat_N,
+        modify_stat_p = .data$modify_stat_n / .data$modify_stat_N,
+        modify_stat_level = ifelse(.data$column %in% "stat_0", translate_text("Overall"), NA_character_)
+      )
+  }
 
 
   # adding headers and footnote ------------------------------------------------
@@ -579,6 +588,8 @@ summarize_custom <- function(data, stat_fn, variable, by, stat_display,
     switch (!is.null(by), by),
     switch (summary_type %in% c("categorical", "dichotomous"), variable)
   )
+  full_data <- data # include missing and ungrouped
+
   data <- data %>%
     dplyr::filter(!is.na(.data[[variable]])) %>%
     dplyr::group_by(dplyr::across(all_of(group_vars)), .drop = FALSE)
@@ -587,7 +598,7 @@ summarize_custom <- function(data, stat_fn, variable, by, stat_display,
   df_stats <- data %>%
     dplyr::group_modify(
       stat_fn,
-      full_data = data,
+      full_data = full_data,
       variable = variable,
       by = by,
       type = summary_type,
