@@ -43,6 +43,7 @@
 #' Review the [themes vignette](https://www.danieldsjoberg.com/gtsummary/articles/themes.html)
 #' to create your own themes.
 #' @examples
+#' \donttest{
 #' # Setting JAMA theme for gtsummary
 #' theme_gtsummary_journal("jama")
 #' # Themes can be combined by including more than one
@@ -56,10 +57,13 @@
 #'
 #' # reset gtsummary themes
 #' reset_gtsummary_theme()
+#' }
 #' @section Example Output:
 #' \if{html}{Example}
 #'
-#' \if{html}{\figure{set_gtsummary_theme_ex1.png}{options: width=60\%}}
+#' \if{html}{\out{
+#' `r man_create_image_tag(file = "set_gtsummary_theme_ex1.png", width = "60")`
+#' }}
 #' @name theme_gtsummary
 #' @seealso [Themes vignette](https://www.danieldsjoberg.com/gtsummary/articles/themes.html)
 #' @seealso [set_gtsummary_theme()], [reset_gtsummary_theme()]
@@ -94,9 +98,9 @@ theme_gtsummary_journal <- function(journal = c("jama", "lancet", "nejm", "qjeco
             {
               new_header_text <-
                 paste0(
-                  x$table_styling$header %>% filter(.data$column == "estimate") %>% pull(.data$label),
+                  x$table_styling$header %>% filter(.data$column == "estimate") %>% pull("label"),
                   " **(**",
-                  x$table_styling$header %>% filter(.data$column == "ci") %>% pull(.data$label),
+                  x$table_styling$header %>% filter(.data$column == "ci") %>% pull("label"),
                   "**)**"
                 )
 
@@ -105,7 +109,7 @@ theme_gtsummary_journal <- function(journal = c("jama", "lancet", "nejm", "qjeco
                 x$table_styling$footnote_abbrev %>%
                 filter(.data$column %in% "estimate") %>%
                 filter(dplyr::row_number() == dplyr::n(), !is.na(.data$footnote)) %>%
-                dplyr::pull(.data$footnote) %>%
+                dplyr::pull("footnote") %>%
                 c("CI = Confidence Interval") %>%
                 paste(collapse = ", ")
               x %>%
@@ -132,7 +136,7 @@ theme_gtsummary_journal <- function(journal = c("jama", "lancet", "nejm", "qjeco
             {
               new_header_text <-
                 paste0(
-                  x$table_styling$header %>% filter(.data$column == "estimate") %>% pull(.data$label),
+                  x$table_styling$header %>% filter(.data$column == "estimate") %>% pull("label"),
                   " **(", style_number(x$inputs$conf.level, scale = 100), "% CI)**"
                 )
 
@@ -141,7 +145,7 @@ theme_gtsummary_journal <- function(journal = c("jama", "lancet", "nejm", "qjeco
                 x$table_styling$footnote_abbrev %>%
                 filter(.data$column %in% "estimate") %>%
                 filter(dplyr::row_number() == dplyr::n(), !is.na(.data$footnote)) %>%
-                dplyr::pull(.data$footnote) %>%
+                dplyr::pull("footnote") %>%
                 c("CI = Confidence Interval") %>%
                 paste(collapse = ", ")
               x %>%
@@ -200,7 +204,7 @@ theme_gtsummary_journal <- function(journal = c("jama", "lancet", "nejm", "qjeco
         "tbl_regression-fn:addnl-fn-to-run" = function(x) {
           new_header_text <-
             paste(
-              x$table_styling$header %>% filter(.data$column == "estimate") %>% pull(.data$label),
+              x$table_styling$header %>% filter(.data$column == "estimate") %>% pull("label"),
               "**(SE)**",
               sep = " "
             )
@@ -209,7 +213,7 @@ theme_gtsummary_journal <- function(journal = c("jama", "lancet", "nejm", "qjeco
             x$table_styling$footnote_abbrev %>%
             filter(.data$column %in% "estimate") %>%
             filter(dplyr::row_number() == dplyr::n(), !is.na(.data$footnote)) %>%
-            dplyr::pull(.data$footnote) %>%
+            dplyr::pull("footnote") %>%
             c("SE = Standard Error") %>%
             paste(collapse = ", ")
 
@@ -298,8 +302,8 @@ theme_gtsummary_printer <- function(print_engine = c("gt", "kable", "kable_extra
 #' @param language String indicating language. Must be one of `"de"` (German),
 #' `"en"` (English), `"es"` (Spanish), `"fr"` (French), `"gu"` (Gujarati),
 #' `"hi"` (Hindi), `"is"` (Icelandic),`"ja"` (Japanese), `"kr"` (Korean),
-#' `"mr"` (Marathi), `"no"` (Norwegian), `"pt"` (Portuguese), `"se"` (Swedish),
-#' `"zh-c,n"` (Chinese Simplified), `"zh-tw"` (Chinese Traditional)
+#' `"nl"` (Dutch), `"mr"` (Marathi), `"no"` (Norwegian), `"pt"` (Portuguese),
+#' `"se"` (Swedish), `"zh-c,n"` (Chinese Simplified), `"zh-tw"` (Chinese Traditional)
 #'
 #' If a language is missing a translation for a word or phrase, please feel free
 #' to reach out on [GitHub](https://github.com/ddsjoberg/gtsummary/issues)
@@ -316,7 +320,7 @@ theme_gtsummary_printer <- function(print_engine = c("gt", "kable", "kable_extra
 #' @export
 theme_gtsummary_language <- function(language = c(
                                        "de", "en", "es", "fr", "gu", "hi", "is", "ja",
-                                       "kr", "mr", "no", "pt", "se", "zh-cn", "zh-tw"
+                                       "kr", "mr", "nl", "no", "pt", "se", "zh-cn", "zh-tw"
                                      ),
                                      decimal.mark = NULL, big.mark = NULL,
                                      iqr.sep = NULL,
