@@ -74,7 +74,7 @@ gtsummary:::df_theme_elements %>%
   gt::cols_label(name = "Theme Element", desc = "Description",
                  example = "Example") %>%
   gt::fmt_markdown(columns = c(name, desc, example)) %>%
-  gt::fmt_missing(columns = everything(), missing_text = "") %>%
+  gt::sub_missing(columns = everything(), missing_text = "") %>%
   gt::tab_options(table.font.size = 'small',
                   data_row.padding = gt::px(1),
                   row_group.padding = gt::px(1))
