@@ -31,4 +31,15 @@ test_that("no errors/warnings with all output types", {
     "32",
     ignore_attr = TRUE
   )
+
+  expect_error(
+    tbl_with_caption <-
+      trial %>%
+      select(age) %>%
+      tbl_summary() %>%
+      modify_table_body(~rename(.x, label2 = label)) %>%
+      modify_column_unhide(label2) %>%
+      modify_caption("captions are great"),
+    NA
+  )
 })
